part of swagger.api;

class JobPostOptions {
  /* Describes a title of the fax job. If not set the current date time will be used as title */
  String title = null;
/* Describes the date the fax should be sent. The format must comply with ISO 8601 and must contain date and time. Date can not be in the past or more than 14 day into the future. If not set the current date time will be used as timeToSend */
  DateTime timeToSend = null;
/* Describes the date the fax can be sent until. The format must comply with ISO 8601 and must contain date and time. DateTime must be 5 minutes after TimeToSend. If not set the date will set to 2030-12-31 */
  DateTime timeToSendUntil = null;
/* Describes if the fax header should used or not for the fax job. If not set the value from api account will be used */
  bool faxHeader = null;
/* Describes the header part from in the fax header (if its used) of the a fax job. If not set the value from api account will be used */
  String faxHeaderFrom = null;
/* Describes the source identifier, which will be displayed during the transmission and appears on the receipt protocol. If not set the value from api account will be used */
  String stationID = null;
/* Describes the Calling Line Identification Presentation (Clip). It is the transferred dialing number before the transmission of the fax document. If not set the value from api account will be used */
  String clip = null;
/* Describes the default International Dialing Code which will be used for fax numbers without international area code. If not set the value from api account will be used */
  String defaultInternationalDialingCode = null;
/* Describes the to used cost center for the fax job. If not set the value from api account will be used */
  String costCenter = null;
/* Describes if the uploaded template documents and resulting preview documents for the fax job should be stored or not. If not set the value from api account will be used */
  bool saveDocuments = null;

  JobPostOptions();

  @override
  String toString() {
    return 'JobPostOptions[title=$title, timeToSend=$timeToSend, timeToSendUntil=$timeToSendUntil, faxHeader=$faxHeader, faxHeaderFrom=$faxHeaderFrom, stationID=$stationID, clip=$clip, defaultInternationalDialingCode=$defaultInternationalDialingCode, costCenter=$costCenter, saveDocuments=$saveDocuments, ]';
  }

  JobPostOptions.fromJson(Map<String, dynamic> json) {
    if (json == null) return;
    title = json['title'];
    timeToSend = json['timeToSend'] == null ? null : DateTime.parse(json['timeToSend']);
    timeToSendUntil = json['timeToSendUntil'] == null ? null : DateTime.parse(json['timeToSendUntil']);
    faxHeader = json['faxHeader'];
    faxHeaderFrom = json['faxHeaderFrom'];
    stationID = json['stationID'];
    clip = json['clip'];
    defaultInternationalDialingCode = json['defaultInternationalDialingCode'];
    costCenter = json['costCenter'];
    saveDocuments = json['saveDocuments'];
  }

  Map<String, dynamic> toJson() {
    return {
      'title': title,
      'timeToSend': timeToSend == null ? '' : timeToSend.toUtc().toIso8601String(),
      'timeToSendUntil': timeToSendUntil == null ? '' : timeToSendUntil.toUtc().toIso8601String(),
      'faxHeader': faxHeader,
      'faxHeaderFrom': faxHeaderFrom,
      'stationID': stationID,
      'clip': clip,
      'defaultInternationalDialingCode': defaultInternationalDialingCode,
      'costCenter': costCenter,
      'saveDocuments': saveDocuments
     };
  }

  static List<JobPostOptions> listFromJson(List<dynamic> json) {
    return json == null ? new List<JobPostOptions>() : json.map((value) => new JobPostOptions.fromJson(value)).toList();
  }

  static Map<String, JobPostOptions> mapFromJson(Map<String, Map<String, dynamic>> json) {
    var map = new Map<String, JobPostOptions>();
    if (json != null && json.length > 0) {
      json.forEach((String key, Map<String, dynamic> value) => map[key] = new JobPostOptions.fromJson(value));
    }
    return map;
  }
}
